'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; /*
                                                                                                                                                                                                                                                                              Copyright (c) 2018 Uber Technologies, Inc.
                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                              This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                              LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                              */


exports.getOverride = getOverride;
exports.getOverrideProps = getOverrideProps;
exports.toObjectOverride = toObjectOverride;
exports.getOverrides = getOverrides;
exports.mergeOverrides = mergeOverrides;
exports.mergeOverride = mergeOverride;

var _react = require('react');

var React = _interopRequireWildcard(_react);

var _deepMerge = require('../utils/deep-merge');

var _deepMerge2 = _interopRequireDefault(_deepMerge);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

/**
 * Given an override argument, returns the component implementation override if it exists
 */
function getOverride(override) {
  // Check if override is OverrideObjectT
  if (override && (typeof override === 'undefined' ? 'undefined' : _typeof(override)) === 'object') {
    // Remove this 'any' once this flow issue is fixed:
    // https://github.com/facebook/flow/issues/6666
    // eslint-disable-next-line flowtype/no-weak-types
    return override.component;
  }
  // Otherwise it must be a component type (function or class) or null/undefined
  return override;
}

/**
 * Given an override argument, returns the override props that should be passed
 * to the component when rendering it.
 */
function getOverrideProps(override) {
  if (override && (typeof override === 'undefined' ? 'undefined' : _typeof(override)) === 'object') {
    return _extends({}, override.props, {
      // $FlowFixMe
      $style: override.style
    });
  }
  return {};
}

/**
 * Coerces an override argument into an override object
 * (sometimes it is just an override component)
 */
function toObjectOverride(override) {
  if (typeof override === 'function') {
    return {
      component: override
    };
  }
  // Flow can't figure out that typeof 'function' above will
  // catch React.StatelessFunctionalComponent
  // (probably related to https://github.com/facebook/flow/issues/6666)
  // eslint-disable-next-line flowtype/no-weak-types
  return override || {};
}

/**
 * Get a convenient override array that will always have [component, props]
 */
function getOverrides(override, defaultComponent) {
  var component = getOverride(override) || defaultComponent;
  var props = getOverrideProps(override);
  return [component, props];
}

/**
 * Merges two overrides objects – this is useful if you want to inject your own
 * overrides into a child component, but also accept further overrides from
 * from upstream. See `mergeOverride` below.
 */
function mergeOverrides() {
  var target = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var source = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var allIdentifiers = Object.keys(_extends({}, target, source));
  return allIdentifiers.reduce(function (acc, name) {
    acc[name] = mergeOverride(toObjectOverride(target[name]), toObjectOverride(source[name]));
    return acc;
  }, {});
}

/**
 * Merges two override objects using the following behavior:
 * - Component implementation from the source (parent) replaces target
 * - Props and styles are both deep merged
 */
function mergeOverride(target, source) {
  // Shallow merge should handle `component`
  var merged = _extends({}, target, source);
  // Props just use deep merge
  if (target.props && source.props) {
    merged.props = (0, _deepMerge2.default)({}, target.props, source.props);
  }
  // Style overrides need special merging since they may be functions
  if (target.style && source.style) {
    merged.style = mergeStyleOverrides(target.style, source.style);
  }
  return merged;
}

/**
 * Since style overrides can be an object *or* a function, we need to handle
 * the case that one of them is a function. We do this by returning a new
 * function that deep emrges the result of each style override
 */
function mergeStyleOverrides(target, source) {
  // Simple case of both objects
  if ((typeof target === 'undefined' ? 'undefined' : _typeof(target)) === 'object' && (typeof source === 'undefined' ? 'undefined' : _typeof(source)) === 'object') {
    return (0, _deepMerge2.default)({}, target, source);
  }

  // At least one is a function, return a new composite function
  return function () {
    return (0, _deepMerge2.default)({}, typeof target === 'function' ? target.apply(undefined, arguments) : target, typeof source === 'function' ? source.apply(undefined, arguments) : source);
  };
}