'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /*
                                                                                                                                                                                                                                                                  Copyright (c) 2018 Uber Technologies, Inc.
                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                  This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                  LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                  */

/*global module */

//$FlowFixMe


var _react = require('react');

var React = _interopRequireWildcard(_react);

var _react2 = require('@storybook/react');

var _styletronReact = require('styletron-react');

var _styles = require('../styles');

var _storybookReadme = require('storybook-readme');

var _inputComponent = require('../../rfcs/input-component.md');

var _inputComponent2 = _interopRequireDefault(_inputComponent);

var _index = require('./index');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

var Button = (0, _styles.styled)('button', function (_ref) {
  var $theme = _ref.$theme;

  return _extends({}, $theme.typography.font300, {
    display: 'block',
    paddingTop: '10px',
    paddingRight: '12px',
    paddingBottom: '10px',
    paddingLeft: '12px',
    marginTop: '8px',
    width: '100%',
    borderRadius: $theme.sizing.scale100,
    borderWidth: 'none'
  });
});

var InputIcon = (0, _styles.styled)('span', function (props) {
  return {
    width: '16px',
    display: 'flex',
    alignItems: 'center',
    padding: props.$position === 'left' ? '0 0 0 12px' : props.$position === 'right' ? '0 12px 0 0' : '0',
    ':before': {
      content: '""',
      display: 'inline-block',
      boxSizing: 'border-box',
      verticalAlign: 'middle',
      width: '16px',
      height: '16px',
      borderRadius: '50%',
      backgroundColor: props.$isFocused ? props.$theme.colors.primary : '#999999'
    }
  };
});

var RootWithStyle = (0, _styletronReact.withStyle)(_index.StyledInputContainer, function (props) {
  var $disabled = props.$disabled,
      $error = props.$error,
      $isFocused = props.$isFocused,
      _props$$theme = props.$theme,
      colors = _props$$theme.colors,
      sizing = _props$$theme.sizing;

  return {
    borderColor: $disabled ? colors.borderAlt : $error ? colors.borderError : $isFocused ? 'darkseagreen' : colors.border,
    boxShadow: '0 0 ' + sizing.scale100 + ' ' + ($disabled ? 'transparent' : $error ? colors.shadowError : $isFocused ? 'lightseagreen' : 'transparent')
  };
});

var TextHighlight = (0, _styles.styled)('span', function (_ref2) {
  var $theme = _ref2.$theme;

  return { color: $theme.colors.primary };
});

(0, _react2.storiesOf)('Input', module).addDecorator((0, _storybookReadme.withReadme)(_inputComponent2.default))
// .add('Passing dynamic props', () => {
//   return <MyComponent />;
// })
.add('Controlled and uncontrolled input', function () {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.Input, { placeholder: 'Controlled input' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, { placeholder: 'Uncontrolled (stateful) input' })
  );
}).add('Input size', function () {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulInput, { placeholder: 'Default input' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, { size: _index.SIZE.compact, placeholder: 'Compact input' })
  );
}).add('Input state', function () {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulInput, { size: _index.SIZE.compact, placeholder: 'Default input' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, {
      initialState: { value: 'uber' },
      autoFocus: true,
      startEnhancer: '@',
      endEnhancer: '.com',
      size: _index.SIZE.compact,
      placeholder: 'Initially focused input'
    }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, {
      size: _index.SIZE.compact,
      error: true,
      placeholder: 'Input in an error state'
    }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, {
      startEnhancer: '@',
      endEnhancer: '.com',
      size: _index.SIZE.compact,
      error: true,
      placeholder: 'Input with enhancers in an error state'
    }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, { size: _index.SIZE.compact, disabled: true, placeholder: 'Disabled input' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, {
      startEnhancer: '@',
      endEnhancer: '.com',
      size: _index.SIZE.compact,
      disabled: true,
      placeholder: 'Disabled input with enhancers'
    })
  );
}).add('Input enhancers', function () {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulInput, { startEnhancer: '@', placeholder: 'Input with a startEnhancer' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, { endEnhancer: '.00', placeholder: 'Input with an endEnhancer' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, {
      startEnhancer: '@',
      endEnhancer: '.00',
      placeholder: 'Input with start and end enhancers'
    }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, {
      startEnhancer: React.createElement(InputIcon, null),
      endEnhancer: React.createElement(InputIcon, null),
      placeholder: 'Input with element type enhancers'
    }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, {
      startEnhancer: function startEnhancer(_ref3) {
        var $isFocused = _ref3.$isFocused;

        return $isFocused ? React.createElement(
          TextHighlight,
          null,
          '@'
        ) : '@';
      },
      endEnhancer: function endEnhancer(_ref4) {
        var $isFocused = _ref4.$isFocused;

        return $isFocused ? React.createElement(
          TextHighlight,
          null,
          '.00'
        ) : '.00';
      },
      placeholder: 'Input with function type enhancers. Shared props are passed into an enhancer func'
    })
  );
}).add('Input with Search tags', function () {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulInput, {
      label: 'Input with search tags',
      overrides: {
        Input: (0, _styletronReact.withStyle)(_index.StyledInput, function (props) {
          return { width: 'auto' };
        }),
        InputContainer: (0, _styletronReact.withStyle)(_index.StyledInputContainer, function (props) {
          return {
            flexWrap: 'wrap',
            padding: '5px',
            alignItems: 'center',
            position: 'relative',
            backgroundColor: 'white',
            borderColor: '#276EF1'
          };
        }),
        After: function After(props) {
          var Img = (0, _styles.styled)('img', function (props) {
            return {
              marginLeft: 'auto',
              position: 'absolute',
              right: '10px'
            };
          });
          return React.createElement(Img, {
            src: 'data:image/svg+xml;utf8,<svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" clip-rule="evenodd" d="M8 16C12.4183 16 16 12.4183 16 8C16 3.58173 12.4183 0 8 0C3.58173 0 0 3.58173 0 8C0 12.4183 3.58173 16 8 16ZM6.03033 4.96967C5.73743 4.67679 5.26257 4.67679 4.96967 4.96967C4.67676 5.26257 4.67676 5.73743 4.96967 6.03033L6.93933 8L4.96967 9.96967C4.67676 10.2626 4.67676 10.7374 4.96967 11.0303C5.26257 11.3232 5.73743 11.3232 6.03033 11.0303L8 9.06067L9.96967 11.0303C10.2626 11.3232 10.7374 11.3232 11.0303 11.0303C11.3232 10.7374 11.3232 10.2626 11.0303 9.96967L9.06067 8L11.0303 6.03033C11.3232 5.73743 11.3232 5.26257 11.0303 4.96967C10.7374 4.67679 10.2626 4.67679 9.96967 4.96967L8 6.93933L6.03033 4.96967Z" fill="#999999"/></svg>'
          });
        },
        Before: function Before(props) {
          var Icon = (0, _styles.styled)('span', function (props) {
            return {
              fontWeight: 'bold',
              display: 'flex',
              alignItems: 'center',
              padding: '5px',
              margin: '5px',
              borderWidth: '1px',
              borderColor: '#276EF1',
              color: '#276EF1',
              borderRadius: '7px',
              lineHeight: '24px',
              backgroundColor: '#EDF3FE'
            };
          });
          var Img = (0, _styles.styled)('img', function (props) {
            return {};
          });
          return React.createElement(
            React.Fragment,
            null,
            React.createElement(Img, {
              src: 'data:image/svg+xml;utf8,<svg width="15" height="15" viewBox="0 0 15 15" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M9 9L13 13M10 5C10 7.76142 7.76142 10 5 10C2.23858 10 0 7.76142 0 5C0 2.23858 2.23858 0 5 0C7.76142 0 10 2.23858 10 5Z" transform="translate(1 1)" stroke="#1B6DE0" stroke-width="2" stroke-linecap="round"/></svg>'
            }),
            ['tag 1 to search', 'tag 2 to search', 'tag 3 to search', 'tag 4 to search', 'tag 5 to search', 'tag 6 to search', 'tag 7 to search', 'tag 8 to search'].map(function (text) {
              return React.createElement(
                Icon,
                { key: text },
                text,
                React.createElement(Img, {
                  src: 'data:image/svg+xml;utf8,<svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" clip-rule="evenodd" d="M0.195262 0.195262C0.455612 -0.0650874 0.877722 -0.0650874 1.13807 0.195262L3.33333 2.39052L5.5286 0.195262C5.78895 -0.0650874 6.21106 -0.0650874 6.4714 0.195262C6.73175 0.455612 6.73175 0.877722 6.4714 1.13807L4.27614 3.33333L6.4714 5.5286C6.73175 5.78895 6.73175 6.21106 6.4714 6.4714C6.21106 6.73175 5.78895 6.73175 5.5286 6.4714L3.33333 4.27614L1.13807 6.4714C0.877722 6.73175 0.455612 6.73175 0.195262 6.4714C-0.0650874 6.21106 -0.0650874 5.78895 0.195262 5.5286L2.39052 3.33333L0.195262 1.13807C-0.0650874 0.877722 -0.0650874 0.455612 0.195262 0.195262Z" transform="translate(4.66675 4.6665)" fill="#276EF1"/></svg>'
                })
              );
            })
          );
        }
      },
      placeholder: 'Start searching'
    })
  );
}).add('Input with Before and After', function () {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulInput, {
      overrides: {
        Before: function Before(props) {
          return React.createElement(InputIcon, _extends({}, props, { $position: 'left' }));
        }
      },
      placeholder: 'Input with a Before component'
    }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, {
      overrides: {
        After: function After(props) {
          return React.createElement(InputIcon, _extends({}, props, { $position: 'right' }));
        }
      },
      placeholder: 'Input with an After component'
    })
  );
}).add('Input with a with custom component override, style overrides and extra props passed', function () {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulInput, {
      overrides: { InputContainer: { component: RootWithStyle } },
      autoFocus: true,
      placeholder: 'Input with a custom InputContainer override'
    }),
    React.createElement('br', null),
    React.createElement(_index.StatefulInput, {
      overrides: {
        Input: {
          props: { 'data-test': 'test' },
          style: { color: '#00F' }
        }
      },
      initialState: {
        value: "With a 'data-test' attrs passes to the input and text style override"
      },
      placeholder: 'With a \'data-test\' attrs passes to the input and text style override'
    })
  );
}).add('Input with a ref', function () {
  var inputRef = React.createRef();
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulInput, { inputRef: inputRef, placeholder: 'With input ref' }),
    React.createElement(
      Button,
      {
        onClick: function onClick() {
          inputRef.current && inputRef.current.focus();
        }
      },
      'Click here to focus input'
    )
  );
});