'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ModalFooter = exports.ModalBody = exports.ModalHeader = exports.Close = exports.Dialog = exports.DialogContainer = exports.Backdrop = exports.Root = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /*
                                                                                                                                                                                                                                                                  Copyright (c) 2018 Uber Technologies, Inc.
                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                  This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                  LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                  */


var _styles = require('../styles');

var _constants = require('./constants');

function getSizeStyles($size) {
  var styles = {
    maxWidth: '100%',
    width: null
  };

  if (typeof $size === 'number') {
    styles.width = $size + 'px';
  } else if (_constants.SIZE.hasOwnProperty($size)) {
    styles.width = _constants.SIZE_WIDTHS[$size];
  } else if (typeof $size === 'string') {
    styles.width = $size;
  }
  if ($size === _constants.SIZE.full) {
    styles.alignSelf = 'stretch';
  }

  return styles;
}

var Root = exports.Root = (0, _styles.styled)('div', function (props) {
  var $isOpen = props.$isOpen,
      $theme = props.$theme;

  return {
    position: 'fixed',
    overflow: 'auto',
    // Maybe this should be dynamic?
    zIndex: $theme.zIndex.modal,
    right: 0,
    bottom: 0,
    top: 0,
    left: 0,
    pointerEvents: $isOpen ? 'auto' : 'none'
  };
});

var Backdrop = exports.Backdrop = (0, _styles.styled)('div', function (props) {
  var $animate = props.$animate,
      $isOpen = props.$isOpen,
      $isVisible = props.$isVisible,
      $theme = props.$theme;

  return _extends({
    zIndex: -1,
    position: 'fixed',
    right: 0,
    bottom: 0,
    top: 0,
    left: 0,
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    // Remove grey highlight
    WebkitTapHighlightColor: 'transparent',
    // Disable scroll capabilities.
    touchAction: 'none',
    opacity: $isVisible && $isOpen ? 1 : 0
  }, $animate ? {
    transitionProperty: 'opacity',
    transitionDuration: $theme.animation.timing400,
    transitionTimingFunction: $theme.animation.easeOutCurve
  } : null);
});

var DialogContainer = exports.DialogContainer = (0, _styles.styled)('div', function (props) {
  return {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    width: '100%',
    minHeight: '100%',
    pointerEvents: 'none',
    userSelect: 'none'
  };
});

var Dialog = exports.Dialog = (0, _styles.styled)('div', function (props) {
  var $animate = props.$animate,
      $isOpen = props.$isOpen,
      $isVisible = props.$isVisible,
      $size = props.$size,
      $theme = props.$theme;

  return _extends({
    position: 'relative',
    backgroundColor: $theme.colors.background,
    borderRadius: $theme.borders.useRoundedCorners ? $theme.borders.radius200 : '0px',
    margin: $theme.sizing.scale600,
    textAlign: 'left'
  }, getSizeStyles($size), {

    // Animation
    opacity: $isVisible && $isOpen ? 1 : 0,
    transform: $isVisible ? 'translateY(0)' : 'translateY(20px)'
  }, $animate ? {
    transitionProperty: 'opacity, transform',
    transitionDuration: $theme.animation.timing400,
    transitionTimingFunction: $theme.animation.easeOutCurve
  } : null, {

    // Reset interactivity properties set by container
    userSelect: 'text',
    pointerEvents: $isOpen ? 'all' : 'none',

    // We move focus to the modal, but we don't want the blue outline style
    ':focus': {
      outline: 'none'
    }
  });
});

var Close = exports.Close = (0, _styles.styled)('button', function (props) {
  var $theme = props.$theme;

  return {
    // Reset button styles
    border: '0',
    background: 'transparent',
    outline: 0,
    padding: 0,

    // Positioning
    position: 'absolute',
    top: $theme.sizing.scale500,
    right: $theme.sizing.scale500,
    width: $theme.sizing.scale800,
    height: $theme.sizing.scale800,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    cursor: 'pointer',
    color: $theme.colors.mono700,
    transitionProperty: 'color',
    transitionDuration: $theme.animation.timing100,
    ':hover': {
      color: $theme.colors.mono800
    }
  };
});

var ModalHeader = exports.ModalHeader = (0, _styles.styled)('div', function (_ref) {
  var $theme = _ref.$theme;
  return _extends({}, $theme.typography.font500, {
    color: $theme.colors.black,
    marginTop: $theme.sizing.scale900,
    marginBottom: $theme.sizing.scale600,
    marginLeft: $theme.sizing.scale800,
    // Slightly more margin than left side to leave room for close button
    marginRight: $theme.sizing.scale900
  });
});

var ModalBody = exports.ModalBody = (0, _styles.styled)('div', function (_ref2) {
  var $theme = _ref2.$theme;
  return _extends({}, $theme.typography.font300, {
    color: $theme.colors.mono800,
    marginTop: $theme.sizing.scale600,
    marginLeft: $theme.sizing.scale800,
    marginRight: $theme.sizing.scale800,
    marginBottom: $theme.sizing.scale700
  });
});

var ModalFooter = exports.ModalFooter = (0, _styles.styled)('div', function (_ref3) {
  var $theme = _ref3.$theme;
  return _extends({}, $theme.typography.font300, {
    marginTop: $theme.sizing.scale700,
    marginLeft: $theme.sizing.scale800,
    marginRight: $theme.sizing.scale800,
    paddingTop: $theme.sizing.scale500,
    paddingBottom: $theme.sizing.scale500,
    textAlign: 'right',
    borderTopWidth: '1px',
    borderTopStyle: 'solid',
    borderTopColor: $theme.colors.mono400
  });
});