'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.tests = exports.suite = undefined;

var _tests$SELECT$tests$S;

var _react = require('react');

var React = _interopRequireWildcard(_react);

var _index = require('./index');

var _constants = require('./constants');

var _examplesColors = require('./examples-colors');

var _examplesColors2 = _interopRequireDefault(_examplesColors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; } /*
                                                                                                                                                                                                                  Copyright (c) 2018 Uber Technologies, Inc.
                                                                                                                                                                                                                  
                                                                                                                                                                                                                  This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                  LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                  */

/* eslint-disable react/display-name*/
/* eslint-disable no-console*/

var emptyOption = { id: '', label: '' };

var suite = exports.suite = 'Select Test Suite';
var tests = exports.tests = {
  SELECT: 'Select',
  SELECT_DISABLED_OPTIONS: 'Select Disabled Options',
  SELECT_SEARCH: 'Select Search',
  MULTI_SELECT: 'Multi-Select',
  MULTI_SELECT_SEARCH: 'Multi-Select Search',
  MULTI_SELECT_CUSTOM_LABELS: 'Multi-Select Custom Labels'
};

var onTextInputChange = function onTextInputChange(e) {
  //$FlowFixMe
  console.log('Text has changed to:' + e.target.value);
};

var onChange = function onChange(_ref) {
  var event = _ref.event,
      type = _ref.type,
      _ref$option = _ref.option,
      option = _ref$option === undefined ? emptyOption : _ref$option;

  if (type === _constants.STATE_CHANGE_TYPE.select) {
    // eslint-disable-next-line no-console
    console.log('Selected option:' + option.id);
  }
};

var onChangeMultiSelect = function onChangeMultiSelect(_ref2) {
  var event = _ref2.event,
      type = _ref2.type,
      _ref2$option = _ref2.option,
      option = _ref2$option === undefined ? emptyOption : _ref2$option,
      selectedOptions = _ref2.selectedOptions;

  switch (type) {
    case _constants.STATE_CHANGE_TYPE.select:
      // eslint-disable-next-line no-console
      console.log('Selected id:' + option.id);
      break;
    case _constants.STATE_CHANGE_TYPE.unselect:
      // eslint-disable-next-line no-console
      console.log('Unselected id:' + option.id);
      break;
  }
};

exports.default = (_tests$SELECT$tests$S = {}, _defineProperty(_tests$SELECT$tests$S, tests.SELECT, function () {
  return React.createElement(_index.StatefulSelect, {
    options: _examplesColors2.default,
    getOptionLabel: function getOptionLabel(option) {
      return option.id;
    },
    rows: 10,
    placeholder: 'Choose a color',
    onChange: onChange
  });
}), _defineProperty(_tests$SELECT$tests$S, tests.SELECT_DISABLED_OPTIONS, function () {
  return React.createElement(_index.StatefulSelect, {
    options: [{
      id: 'red',
      label: 'Red'
    }, {
      id: 'orange',
      label: 'Orange',
      disabled: true
    }, {
      id: 'green',
      label: 'Green'
    }, {
      id: 'blue',
      label: 'Blue',
      disabled: true
    }],
    placeholder: 'Choose a color',
    onChange: onChange
  });
}), _defineProperty(_tests$SELECT$tests$S, tests.MULTI_SELECT, function () {
  return React.createElement(_index.StatefulSelect, {
    options: _examplesColors2.default,
    getOptionLabel: function getOptionLabel(option) {
      return option.id;
    },
    multiple: true,
    initialState: {
      selectedOptions: [_examplesColors2.default[1], _examplesColors2.default[3]]
    },
    onChange: onChange
  });
}), _defineProperty(_tests$SELECT$tests$S, tests.MULTI_SELECT_SEARCH, function () {
  return React.createElement(_index.StatefulSelect, {
    type: _index.TYPE.search,
    options: function options() {
      return new Promise(function (resolve) {
        setTimeout(function () {
          resolve(_examplesColors2.default);
        }, 1000);
      });
    },
    getOptionLabel: function getOptionLabel(option) {
      return option.id;
    },
    rows: 8,
    multiple: true,
    filterable: true,
    placeholder: 'Start searching',
    onTextInputChange: onTextInputChange,
    onChange: onChangeMultiSelect
  });
}), _defineProperty(_tests$SELECT$tests$S, tests.MULTI_SELECT_CUSTOM_LABELS, function () {
  function CustomOptionLabel(_ref3) {
    var option = _ref3.option,
        _ref3$showColor = _ref3.showColor,
        showColor = _ref3$showColor === undefined ? false : _ref3$showColor;

    return React.createElement(
      'div',
      { style: { display: 'inline-flex', alignItems: 'center' } },
      React.createElement('div', {
        style: {
          borderRadius: '100%',
          width: '10px',
          height: '10px',
          backgroundColor: option.color,
          marginRight: '5px'
        }
      }),
      React.createElement(
        'div',
        null,
        option.id,
        showColor && ' (' + option.color + ')'
      )
    );
  }

  return React.createElement(_index.StatefulSelect, {
    options: _examplesColors2.default,
    getOptionLabel: function getOptionLabel(option) {
      return React.createElement(CustomOptionLabel, { option: option, showColor: true });
    },
    getSelectedOptionLabel: function getSelectedOptionLabel(option) {
      return React.createElement(CustomOptionLabel, { option: option });
    },
    initialState: {
      selectedOptions: [_examplesColors2.default[2]]
    },
    rows: 8,
    multiple: true,
    onTextInputChange: onTextInputChange,
    onChange: onChangeMultiSelect
  });
}), _tests$SELECT$tests$S);