'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Root = exports.ActionIcon = exports.Action = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /*
                                                                                                                                                                                                                                                                  Copyright (c) 2018 Uber Technologies, Inc.
                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                  This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                  LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                  */


exports.getBackgroundColor = getBackgroundColor;
exports.getColor = getColor;
exports.getHoverBackgroundColor = getHoverBackgroundColor;

var _constants = require('./constants');

var _index = require('../styles/index');

function getBackgroundColor(props) {
  var $color = props.$color,
      $isActive = props.$isActive,
      $isFocused = props.$isFocused,
      $kind = props.$kind,
      $theme = props.$theme;

  var color = getColor($theme, $kind, $color);
  return (0, _index.hexToRgb)(color, $isFocused || $isActive ? '0.2' : '0.06');
}

function getColor($theme) {
  var $kind = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _constants.COLOR_STYLE_KEYS.primary;
  var $color = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '#000';

  if ($kind === 'custom') {
    return $color;
  }
  if ($theme && $theme.colors && $theme.colors[_constants.COLOR_STYLE_KEYS[$kind]]) {
    return $theme.colors[_constants.COLOR_STYLE_KEYS[$kind]];
  }
}

function getHoverBackgroundColor(props) {
  var $color = props.$color,
      $disabled = props.$disabled,
      $kind = props.$kind,
      $theme = props.$theme;

  var color = getColor($theme, $kind, $color);
  return $disabled ? null : (0, _index.hexToRgb)(color, '0.2');
}

var Action = exports.Action = (0, _index.styled)('div', function (props) {
  var $disabled = props.$disabled;

  return {
    display: 'flex',
    alignItems: 'center',
    padding: '12px',
    borderTopRightRadius: '2px',
    borderBottomRightRadius: '2px',
    marginLeft: '8px',
    cursor: $disabled ? 'not-allowed' : 'pointer',
    ':hover': {
      backgroundColor: getBackgroundColor(props)
    }
  };
});

var ActionIcon = exports.ActionIcon = (0, _index.styled)('svg', function () {
  return {};
});

var Root = exports.Root = (0, _index.styled)('span', function (props) {
  var $color = props.$color,
      $disabled = props.$disabled,
      $kind = props.$kind,
      $theme = props.$theme;
  var _$theme$sizing = $theme.sizing,
      scale800 = _$theme$sizing.scale800,
      scale100 = _$theme$sizing.scale100,
      scale300 = _$theme$sizing.scale300,
      font200 = $theme.typography.font200;

  var color = getColor($theme, $kind, $color);
  return _extends({}, font200, {
    display: 'inline-flex',
    height: scale800,
    fontWeight: 'bold',
    margin: '5px',
    alignItems: 'center',
    justifyContent: 'space-between',
    paddingTop: scale100,
    paddingBottom: scale100,
    paddingLeft: scale300,
    borderWidth: '1px',
    borderColor: color,
    color: color,
    opacity: $disabled ? '.56' : null,
    borderRadius: $theme.borders.useRoundedCorners ? $theme.borders.radius100 : '0px',
    cursor: $disabled ? 'not-allowed' : 'auto',
    backgroundColor: getBackgroundColor(props),
    ':hover': {
      backgroundColor: getHoverBackgroundColor(props)
    }
  });
});