'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.tests = undefined;

var _tests$SIMPLE_EXAMPLE;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /*
                                                                                                                                                                                                                                                                  Copyright (c) 2018 Uber Technologies, Inc.
                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                  This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                  LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                  */


var _react = require('react');

var React = _interopRequireWildcard(_react);

var _styletronReact = require('styletron-react');

var _styles = require('../styles');

var _helpers = require('../helpers');

var _index = require('./index');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var Button = (0, _styles.styled)('button', function (_ref) {
  var $theme = _ref.$theme;

  return _extends({}, $theme.typography.font300, {
    display: 'block',
    paddingTop: '10px',
    paddingRight: '12px',
    paddingBottom: '10px',
    paddingLeft: '12px',
    marginTop: '8px',
    width: '100%',
    borderRadius: $theme.sizing.scale100,
    borderWidth: 'none'
  });
});

var TextareaWithStyle = (0, _styletronReact.withStyle)(_index.StyledTextarea, function (props) {
  var $disabled = props.$disabled,
      $error = props.$error,
      $isFocused = props.$isFocused,
      _props$$theme = props.$theme,
      colors = _props$$theme.colors,
      sizing = _props$$theme.sizing;

  return {
    borderColor: $disabled ? colors.borderAlt : $error ? colors.borderError : $isFocused ? 'darkseagreen' : colors.border,
    boxShadow: '0 0 ' + sizing.scale100 + ' ' + ($disabled ? 'transparent' : $error ? colors.shadowError : $isFocused ? 'lightseagreen' : 'transparent')
  };
});

var TextareaWithProps = (0, _helpers.withProps)(_index.StyledTextarea, {
  'data-test': 'test'
});

var tests = exports.tests = {
  SIMPLE_EXAMPLE: 'Controlled and uncontrolled textarea',
  SIZE_EXAMPLE: 'Textarea size',
  STATE_EXAMPLE: 'Textarea state',
  OVERRIDES_EXAMPLE: 'Textarea with style overrides and extra props passed',
  REF_EXAMPLE: 'Textarea with a ref'
};

exports.default = (_tests$SIMPLE_EXAMPLE = {}, _defineProperty(_tests$SIMPLE_EXAMPLE, tests.SIMPLE_EXAMPLE, function Story1() {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.Textarea, { placeholder: 'Controlled textarea' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulTextarea, {
      placeholder: 'Uncontrolled textarea',
      initialState: { value: 'initial value' }
    })
  );
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.SIMPLE_EXAMPLE, function Story2() {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulTextarea, { placeholder: 'Default textarea' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulTextarea, { size: _index.SIZE.compact, placeholder: 'Compact textarea' })
  );
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.STATE_EXAMPLE, function Story3() {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulTextarea, { size: _index.SIZE.compact, placeholder: 'Placeholder' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulTextarea, {
      initialState: { value: 'uber' },
      autoFocus: true,
      size: _index.SIZE.compact,
      placeholder: 'Placeholder'
    }),
    React.createElement('br', null),
    React.createElement(_index.StatefulTextarea, { size: _index.SIZE.compact, error: true, placeholder: 'Placeholder' }),
    React.createElement('br', null),
    React.createElement(_index.StatefulTextarea, {
      size: _index.SIZE.compact,
      disabled: true,
      placeholder: 'Disabled textarea'
    })
  );
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.OVERRIDES_EXAMPLE, function Story4() {
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulTextarea, {
      autoFocus: true,
      overrides: { Input: TextareaWithStyle },
      placeholder: 'With style overrides on the textarea element'
    }),
    React.createElement('br', null),
    React.createElement(_index.StatefulTextarea, {
      label: 'Input with extra props',
      overrides: {
        Input: TextareaWithProps
      },
      placeholder: 'With a \'data-test\' attrs passes to the input element'
    })
  );
}), _defineProperty(_tests$SIMPLE_EXAMPLE, tests.REF_EXAMPLE, function Story5() {
  var inputRef = React.createRef();
  return React.createElement(
    React.Fragment,
    null,
    React.createElement(_index.StatefulTextarea, { inputRef: inputRef, placeholder: 'With textarea input ref' }),
    React.createElement(
      Button,
      {
        onClick: function onClick() {
          inputRef.current && inputRef.current.focus();
        }
      },
      'Click here to focus input'
    )
  );
}), _tests$SIMPLE_EXAMPLE);