'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Input = exports.getInputStyles = exports.InputContainer = exports.getInputContainerStyles = exports.InputEnhancer = exports.Root = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _styles = require('../styles');

var _constants = require('./constants');

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; } /*
                                                                                                                                                                                                                  Copyright (c) 2018 Uber Technologies, Inc.
                                                                                                                                                                                                                  
                                                                                                                                                                                                                  This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                  LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                  */


function getInputPadding(size, sizing) {
  var _SIZE$default$SIZE$co;

  return (_SIZE$default$SIZE$co = {}, _defineProperty(_SIZE$default$SIZE$co, _constants.SIZE.default, {
    paddingTop: sizing.scale400,
    paddingRight: sizing.scale500,
    paddingBottom: sizing.scale400,
    paddingLeft: sizing.scale500
  }), _defineProperty(_SIZE$default$SIZE$co, _constants.SIZE.compact, {
    paddingTop: sizing.scale200,
    paddingRight: sizing.scale500,
    paddingBottom: sizing.scale200,
    paddingLeft: sizing.scale500
  }), _SIZE$default$SIZE$co)[size];
}

function getBorderRadius(adjoined, radius) {
  var _ADJOINED$none$ADJOIN;

  return (_ADJOINED$none$ADJOIN = {}, _defineProperty(_ADJOINED$none$ADJOIN, _constants.ADJOINED.none, radius), _defineProperty(_ADJOINED$none$ADJOIN, _constants.ADJOINED.left, '0 ' + radius + ' ' + radius + ' 0'), _defineProperty(_ADJOINED$none$ADJOIN, _constants.ADJOINED.right, radius + ' 0 0 ' + radius), _defineProperty(_ADJOINED$none$ADJOIN, _constants.ADJOINED.both, '0'), _ADJOINED$none$ADJOIN)[adjoined];
}

function getDecoratorBorderRadius(position, radius) {
  var _ENHANCER_POSITION$st;

  return (_ENHANCER_POSITION$st = {}, _defineProperty(_ENHANCER_POSITION$st, _constants.ENHANCER_POSITION.start, radius + ' 0 0 ' + radius), _defineProperty(_ENHANCER_POSITION$st, _constants.ENHANCER_POSITION.end, '0 ' + radius + ' ' + radius + ' 0'), _ENHANCER_POSITION$st)[position];
}

function getFont(size, typography) {
  var _SIZE$default$SIZE$co2;

  return (_SIZE$default$SIZE$co2 = {}, _defineProperty(_SIZE$default$SIZE$co2, _constants.SIZE.default, typography.font300), _defineProperty(_SIZE$default$SIZE$co2, _constants.SIZE.compact, typography.font200), _SIZE$default$SIZE$co2)[size];
}

var Root = exports.Root = (0, _styles.styled)('div', function (props) {
  var $size = props.$size,
      _props$$theme = props.$theme,
      colors = _props$$theme.colors,
      typography = _props$$theme.typography;

  return _extends({}, getFont($size, typography), {
    color: colors.mono1000,
    display: 'flex',
    width: '100%'
  });
});

var InputEnhancer = exports.InputEnhancer = (0, _styles.styled)('div', function (props) {
  var $position = props.$position,
      $size = props.$size,
      _props$$theme2 = props.$theme,
      colors = _props$$theme2.colors,
      sizing = _props$$theme2.sizing,
      typography = _props$$theme2.typography;

  return _extends({}, getFont($size, typography), {
    color: colors.mono900,
    display: 'flex'
  }, getInputPadding($size, sizing), {
    backgroundColor: colors.mono400,
    borderRadius: getDecoratorBorderRadius($position, sizing.scale100)
  });
});

var getInputContainerStyles = exports.getInputContainerStyles = function getInputContainerStyles(props) {
  var $isFocused = props.$isFocused,
      $adjoined = props.$adjoined,
      $error = props.$error,
      $disabled = props.$disabled,
      $size = props.$size,
      _props$$theme3 = props.$theme,
      colors = _props$$theme3.colors,
      sizing = _props$$theme3.sizing,
      typography = _props$$theme3.typography,
      animation = _props$$theme3.animation;

  return _extends({}, getFont($size, typography), {
    color: $disabled ? colors.mono600 : colors.mono1000,
    boxSizing: 'border-box',
    display: 'flex',
    width: '100%',
    backgroundColor: $disabled ? colors.mono300 : $isFocused ? colors.mono100 : $error ? colors.negative50 : colors.mono200,
    borderWidth: '1px',
    borderStyle: 'solid',
    borderColor: $disabled ? colors.mono300 : $error ? colors.negative400 : $isFocused ? colors.primary400 : colors.mono200,
    borderRadius: getBorderRadius($adjoined, sizing.scale100),
    boxShadow: '0 2px 6px ' + ($disabled ? 'transparent' : $isFocused ? $error ? colors.shadowError : colors.shadowFocus : 'transparent'),
    transitionProperty: 'border, boxShadow, backgroundColor',
    transitionDuration: animation.timing100,
    transitionTimingFunction: animation.easeOutCurve
  });
};

var InputContainer = exports.InputContainer = (0, _styles.styled)('div', getInputContainerStyles);

var getInputStyles = exports.getInputStyles = function getInputStyles(props) {
  var $disabled = props.$disabled,
      $error = props.$error,
      $size = props.$size,
      _props$$theme4 = props.$theme,
      colors = _props$$theme4.colors,
      sizing = _props$$theme4.sizing,
      typography = _props$$theme4.typography;

  return _extends({}, getFont($size, typography), {
    color: $disabled ? colors.mono600 : colors.mono1000,
    caretColor: $error ? colors.negative400 : colors.primary,
    boxSizing: 'border-box',
    backgroundColor: 'transparent',
    borderWidth: '0',
    borderStyle: 'none',
    outline: 'none'
  }, getInputPadding($size, sizing), {
    width: '100%',
    maxWidth: '100%',
    cursor: $disabled ? 'not-allowed' : 'text',
    '::placeholder': {
      color: $disabled ? colors.mono600 : colors.mono700
    }
  });
};

var Input = exports.Input = (0, _styles.styled)('input', getInputStyles);