'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Padding = exports.Inner = exports.Arrow = exports.Body = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /*
                                                                                                                                                                                                                                                                  Copyright (c) 2018 Uber Technologies, Inc.
                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                  This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                  LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                  */


exports.getBodyStyles = getBodyStyles;
exports.getArrowStyles = getArrowStyles;
exports.getInnerStyles = getInnerStyles;

var _styles = require('../styles');

var _constants = require('./constants');

var _utils = require('./utils');

/**
 * Main popover container element that gets positioned next to the anchor
 */
function getBodyStyles(props) {
  var $isOpen = props.$isOpen,
      $isAnimating = props.$isAnimating,
      $placement = props.$placement,
      $popoverOffset = props.$popoverOffset,
      $showArrow = props.$showArrow,
      $theme = props.$theme;


  return _extends({
    position: 'absolute',
    top: 0,
    left: 0,
    zIndex: 1050,
    backgroundColor: $theme.colors.background,
    borderRadius: $theme.borders.useRoundedCorners ? $theme.borders.radius300 : '0px',
    boxShadow: $theme.lighting.shadow600,

    transitionProperty: 'opacity,transform',
    transitionDuration: $isAnimating ? '0.1s' : '0s',
    transitionTimingFunction: $isOpen ? $theme.animation.easeOutCurve : $theme.animation.easeInCurve,
    opacity: $isAnimating && $isOpen ? 1 : 0,
    transform: $isAnimating && $isOpen ? (0, _utils.getEndPosition)($popoverOffset) : (0, _utils.getStartPosition)($popoverOffset, $placement, $showArrow)
  }, (0, _utils.getPopoverMarginStyles)($showArrow, $placement));
}

var Body = exports.Body = (0, _styles.styled)('div', getBodyStyles);

/**
 * Arrow shown between the popover and the anchor element
 */
function getArrowStyles(props) {
  var $arrowOffset = props.$arrowOffset,
      $placement = props.$placement,
      $theme = props.$theme;

  return _extends({
    backgroundColor: $theme.colors.background,
    boxShadow: $theme.lighting.shadow600,
    width: _constants.ARROW_WIDTH + 'px',
    height: _constants.ARROW_WIDTH + 'px',
    transform: 'rotate(45deg)',
    position: 'absolute',
    zIndex: 1 }, (0, _utils.getArrowPositionStyles)($arrowOffset, $placement));
}

var Arrow = exports.Arrow = (0, _styles.styled)('div', getArrowStyles);

/**
 * Extra div that holds the popover content. This extra element
 * is needed for the arrow–the arrow is just a 45deg rotated div,
 * and rendering this extra element on top with a solid background
 * clips the part of the arrow that extends into the popover.
 */
function getInnerStyles(_ref) {
  var $theme = _ref.$theme;

  return {
    backgroundColor: $theme.colors.background,
    borderRadius: $theme.borders.useRoundedCorners ? $theme.borders.radius300 : '0px',
    position: 'relative',
    zIndex: 2 // Above "Arrow"
  };
}

var Inner = exports.Inner = (0, _styles.styled)('div', getInnerStyles);

/**
 * A drop-in component that provides the recommended padding
 * for popovers. Mostly a convenience for users so they don't
 * have to define this themselves.
 */
var Padding = exports.Padding = (0, _styles.styled)('div', {
  padding: '12px'
});