'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SelectSpinner = exports.Option = exports.DropDownItem = exports.DropDown = exports.SelectComponentIcon = exports.SingleSelection = exports.InputContainer = exports.Input = exports.Root = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /*
                                                                                                                                                                                                                                                                  Copyright (c) 2018 Uber Technologies, Inc.
                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                  This source code is licensed under the MIT license found in the
                                                                                                                                                                                                                                                                  LICENSE file in the root directory of this source tree.
                                                                                                                                                                                                                                                                  */


var _index = require('../styles/index');

var _constants = require('./constants');

var _input = require('../input');

var _styledComponents = require('../input/styled-components');

var _styledComponents2 = require('../menu/styled-components');

var Root = exports.Root = (0, _index.styled)('div', function (props) {
  return {
    position: 'relative'
  };
});

var Input = exports.Input = (0, _index.styled)('input', function (props) {
  var $theme = props.$theme;
  var scale300 = $theme.sizing.scale300;

  return _extends({}, (0, _styledComponents.getInputStyles)(_extends({}, props, { $size: _input.SIZE.default })), {
    cursor: 'pointer',
    width: 'auto',
    flexGrow: '1',
    paddingTop: scale300,
    paddingBottom: scale300
  });
});

var InputContainer = exports.InputContainer = (0, _index.styled)('div', function (props) {
  var $theme = props.$theme,
      $isFocused = props.$isFocused;
  var mono700 = $theme.colors.mono700,
      scale300 = $theme.sizing.scale300;

  var color = $isFocused ? {} : { borderColor: mono700 };
  return _extends({}, (0, _styledComponents.getInputContainerStyles)(_extends({}, props, { $size: _input.SIZE.default })), {
    flexWrap: 'wrap',
    paddingLeft: scale300,
    paddingRight: scale300,
    paddingTop: '0',
    paddingBottom: '0',
    alignItems: 'center',
    position: 'relative'
  }, color);
});

var SingleSelection = exports.SingleSelection = (0, _index.styled)('span', function (props) {
  var $theme = props.$theme,
      $disabled = props.$disabled;
  var mono1000 = $theme.colors.mono1000;

  return _extends({}, (0, _styledComponents.getInputStyles)(_extends({}, props, { $size: _input.SIZE.default, $disabled: true })), {
    cursor: $disabled ? 'not-allowed' : 'pointer',
    width: 'auto',
    flexGrow: '1',
    color: mono1000
  });
});

var SelectComponentIcon = exports.SelectComponentIcon = (0, _index.styled)('img', function (props) {
  var $theme = props.$theme,
      $disabled = props.$disabled;
  var _$theme$sizing = $theme.sizing,
      scale300 = _$theme$sizing.scale300,
      scale600 = _$theme$sizing.scale600,
      scale500 = _$theme$sizing.scale500;

  switch (props.$type) {
    case _constants.ICON.clearAll:
      return {
        marginLeft: 'auto',
        position: 'absolute',
        right: scale600,
        cursor: $disabled ? 'not-allowed' : 'pointer'
      };
    case _constants.ICON.select:
      return {
        top: '50%',
        position: 'absolute',
        right: scale600,
        marginRight: scale500
      };
    case _constants.ICON.selected:
      return {
        paddingRight: scale300
      };
    case _constants.ICON.loop:
      return {
        paddingLeft: scale300
      };
    default:
      return {};
  }
});

var DropDown = exports.DropDown = (0, _index.styled)(_styledComponents2.List, function (_ref) {
  var $theme = _ref.$theme,
      $isOpen = _ref.$isOpen,
      $type = _ref.$type;
  return {
    overflowY: 'scroll',
    display: !$isOpen ? 'none' : null,
    top: $type === _constants.TYPE.select ? $theme.sizing.scale600 : null,
    width: 'calc(100% - ' + $theme.sizing.scale600 + ')',
    left: $theme.sizing.scale300,
    position: 'absolute',
    listStyle: 'none',
    borderRadius: $theme.sizing.scale300,
    boxShadow: $theme.lighting.shadow600
  };
});

var DropDownItem = exports.DropDownItem = (0, _index.styled)(_styledComponents2.ListItem, function (_ref2) {
  var $theme = _ref2.$theme;
  return {
    // TODO(#185): revisit after Menu gets condensed styles
    lineHeight: $theme.sizing.scale600
  };
});

var Option = exports.Option = (0, _index.styled)('div', function (props) {
  var $selected = props.$selected,
      disabled = props.disabled,
      $theme = props.$theme;
  var _$theme$colors = $theme.colors,
      mono700 = _$theme$colors.mono700,
      primary400 = _$theme$colors.primary400;

  var padding = $selected ? {
    paddingRight: '0px',
    paddingLeft: '0px'
  } : {
    paddingRight: '18px',
    paddingLeft: '18px'
  };
  return _extends({
    ':hover': {
      cursor: disabled ? 'not-allowed' : 'pointer'
    },
    color: disabled ? mono700 : $selected ? primary400 : null
  }, padding);
});

var SelectSpinner = exports.SelectSpinner = (0, _index.styled)('div', function () {
  return {
    paddingLeft: '50%'
  };
});